#!/bin/sh

# defaults
DRIVERPATH="/opt/lib/modules/$1/" 
FILEPATH="/home/user/.cleven"

# Save mac address
MACADDR="`ifconfig wlan0 | sed -n 's/.*HWaddr \([0-9A-Fa-f:]\+\).*/\1/p'`"

if [ ! -f $FILEPATH/myMAC ]; then
   echo $MACADDR > $FILEPATH/myMAC
fi

# Unload wifi modules
rmmod wl1251_spi 2>/dev/null
rmmod wl1251 2>/dev/null
rmmod wl12xx 2>/dev/null
rmmod mac80211 2>/dev/null
rmmod cfg80211 2>/dev/null
rmmod rfkill_backport 2>/dev/null
rmmod compat_firmware_class 2>/dev/null
rmmod compat 2>/dev/null
# Load bleeding-edge wl1251

insmod $DRIVERPATH/updates/compat/compat.ko
insmod $DRIVERPATH/updates/net/rfkill/rfkill_backport.ko
insmod $DRIVERPATH/updates/net/wireless/cfg80211.ko
insmod $DRIVERPATH/updates/net/mac80211/mac80211.ko
insmod $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251.ko
insmod $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251_spi.ko
   
# Restore mac address
ifconfig wlan0 down hw ether "$MACADDR"

echo "Custom wl1251 module loaded (with injection) :)"